@@ -515,6 +515,20 @@ TF032.check.getAmatBmat.dense.C <- function()
 }
 
 
+TF033.check.equality.HugeData <- function()
+{
+	memory.limit(7500)
+	data(HugeData)
+	try(fit <- anovaVCA(y~VC1/VC2, HugeData), silent=TRUE)
+	if(class(fit) == "try-error")
+	{
+		cat("\n\n########################################################################\n")
+		cat(  "\n'TF033.check.equality.HugeData' cannot be run due to memory limitations!")
+		cat(  "\n########################################################################\n\n")	
+	}
+	else
+		checkEquals(round(as.numeric(fit$aov.tab[-1, "VC"]), 4), c(5173.4411, 12268.7307, 13197.6746))
+}
 
 
 
